@@ -95,16 +95,18 @@ const (
 
 // Options for New method
 type Options struct {
-	Creds  *credentials.Credentials
-	Secure bool
+	Creds     *credentials.Credentials
+	Secure    bool
+	Transport http.RoundTripper
 	// Add future fields here
 }
 
 // New - instantiate minio admin client
+// Deprecated: please use NewWithOptions
 func New(endpoint string, accessKeyID, secretAccessKey string, secure bool) (*AdminClient, error) {
 	creds := credentials.NewStaticV4(accessKeyID, secretAccessKey, "")
 
-	clnt, err := privateNew(endpoint, creds, secure)
+	clnt, err := privateNew(endpoint, &Options{Creds: creds, Secure: secure})
 	if err != nil {
 		return nil, err
 	}
@@ -113,14 +115,14 @@ func New(endpoint string, accessKeyID, secretAccessKey string, secure bool) (*Ad
 
 // NewWithOptions - instantiate minio admin client with options.
 func NewWithOptions(endpoint string, opts *Options) (*AdminClient, error) {
-	clnt, err := privateNew(endpoint, opts.Creds, opts.Secure)
+	clnt, err := privateNew(endpoint, opts)
 	if err != nil {
 		return nil, err
 	}
 	return clnt, nil
 }
 
-func privateNew(endpoint string, creds *credentials.Credentials, secure bool) (*AdminClient, error) {
+func privateNew(endpoint string, opts *Options) (*AdminClient, error) {
 	// Initialize cookies to preserve server sent cookies if any and replay
 	// them upon each request.
 	jar, err := cookiejar.New(&cookiejar.Options{PublicSuffixList: publicsuffix.List})
@@ -129,7 +131,7 @@ func privateNew(endpoint string, creds *credentials.Credentials, secure bool) (*
 	}
 
 	// construct endpoint.
-	endpointURL, err := getEndpointURL(endpoint, secure)
+	endpointURL, err := getEndpointURL(endpoint, opts.Secure)
 	if err != nil {
 		return nil, err
 	}
@@ -137,18 +139,23 @@ func privateNew(endpoint string, creds *credentials.Credentials, secure bool) (*
 	clnt := new(AdminClient)
 
 	// Save the credentials.
-	clnt.credsProvider = creds
+	clnt.credsProvider = opts.Creds
 
 	// Remember whether we are using https or not
-	clnt.secure = secure
+	clnt.secure = opts.Secure
 
 	// Save endpoint URL, user agent for future uses.
 	clnt.endpointURL = endpointURL
 
+	tr := opts.Transport
+	if tr == nil {
+		tr = DefaultTransport(opts.Secure)
+	}
+
 	// Instantiate http client and bucket location cache.
 	clnt.httpClient = &http.Client{
 		Jar:       jar,
-		Transport: DefaultTransport(secure),
+		Transport: tr,
 	}
 
 	// Add locked pseudo-random number generator.
@@ -169,6 +176,7 @@ func (adm *AdminClient) SetAppInfo(appName string, appVersion string) {
 }
 
 // SetCustomTransport - set new custom transport.
+// Deprecated: please use Options{Transport: tr} to provide custom transport.
 func (adm *AdminClient) SetCustomTransport(customHTTPTransport http.RoundTripper) {
 	// Set this to override default transport
 	// ``http.DefaultTransport``.
