@@ -23,6 +23,8 @@ import (
 	"context"
 	"encoding/json"
 	"net/http"
+	"net/url"
+	"strconv"
 	"time"
 )
 
@@ -204,11 +206,22 @@ type DataUsageInfo struct {
 
 	// Deprecated kept here for backward compatibility reasons.
 	BucketSizes map[string]uint64 `json:"bucketsSizes"`
+
+	// Server capacity related data
+	TotalCapacity     uint64 `json:"capacity"`
+	TotalFreeCapacity uint64 `json:"freeCapacity"`
+	TotalUsedCapacity uint64 `json:"usedCapacity"`
 }
 
 // DataUsageInfo - returns data usage of the current object API
 func (adm *AdminClient) DataUsageInfo(ctx context.Context) (DataUsageInfo, error) {
-	resp, err := adm.executeMethod(ctx, http.MethodGet, requestData{relPath: adminAPIPrefix + "/datausageinfo"})
+	values := make(url.Values)
+	values.Set("capacity", "true") // We can make this configurable in future but for now its fine.
+
+	resp, err := adm.executeMethod(ctx, http.MethodGet, requestData{
+		relPath:     adminAPIPrefix + "/datausageinfo",
+		queryValues: values,
+	})
 	defer closeResponse(resp)
 	if err != nil {
 		return DataUsageInfo{}, err
@@ -411,11 +424,25 @@ type ServerProperties struct {
 type DiskMetrics struct {
 	LastMinute map[string]TimedAction `json:"lastMinute,omitempty"`
 	APICalls   map[string]uint64      `json:"apiCalls,omitempty"`
-	// Captures all data availability errors such as permission denied, faulty disk and timeout errors.
+
+	// TotalTokens set per drive max concurrent I/O.
+	TotalTokens uint32 `json:"totalTokens,omitempty"`
+	// TotalWaiting the amount of concurrent I/O waiting on disk
+	TotalWaiting uint32 `json:"totalWaiting,omitempty"`
+
+	// Captures all data availability errors such as
+	// permission denied, faulty disk and timeout errors.
 	TotalErrorsAvailability uint64 `json:"totalErrorsAvailability,omitempty"`
 	// Captures all timeout only errors
 	TotalErrorsTimeout uint64 `json:"totalErrorsTimeout,omitempty"`
 
+	// Total writes on disk (could be empty if the feature
+	// is not enabled on the server)
+	TotalWrites uint64 `json:"totalWrites,omitempty"`
+	// Total deletes on disk (could be empty if the feature
+	// is not enabled on the server)
+	TotalDeletes uint64 `json:"totalDeletes,omitempty"`
+
 	// Deprecated: Use LastMinute instead. Not populated from servers after July 2022.
 	APILatencies map[string]interface{} `json:"apiLatencies,omitempty"`
 }
@@ -451,13 +478,36 @@ type Disk struct {
 	DiskIndex int `json:"disk_index"`
 }
 
+// ServerInfoOpts ask for additional data from the server
+type ServerInfoOpts struct {
+	Metrics bool
+}
+
+// WithDriveMetrics asks server to return additional metrics per drive
+func WithDriveMetrics(metrics bool) func(*ServerInfoOpts) {
+	return func(opts *ServerInfoOpts) {
+		opts.Metrics = metrics
+	}
+}
+
 // ServerInfo - Connect to a minio server and call Server Admin Info Management API
 // to fetch server's information represented by infoMessage structure
-func (adm *AdminClient) ServerInfo(ctx context.Context) (InfoMessage, error) {
+func (adm *AdminClient) ServerInfo(ctx context.Context, options ...func(*ServerInfoOpts)) (InfoMessage, error) {
+	srvOpts := &ServerInfoOpts{}
+
+	for _, o := range options {
+		o(srvOpts)
+	}
+
+	values := make(url.Values)
+	values.Set("metrics", strconv.FormatBool(srvOpts.Metrics))
+
 	resp, err := adm.executeMethod(ctx,
 		http.MethodGet,
-		requestData{relPath: adminAPIPrefix + "/info"},
-	)
+		requestData{
+			relPath:     adminAPIPrefix + "/info",
+			queryValues: values,
+		})
 	defer closeResponse(resp)
 	if err != nil {
 		return InfoMessage{}, err
