@@ -66,6 +66,7 @@ type SpeedtestOpts struct {
 	StorageClass string        // Choose type of storage-class to be used while performing I/O
 	Bucket       string        // Choose a custom bucket name while performing I/O
 	NoClear      bool          // Avoid cleanup after running an object speed test
+	EnableSha256 bool          // Enable calculating sha256 for uploads
 }
 
 // Speedtest - perform speedtest on the MinIO servers
@@ -101,6 +102,9 @@ func (adm *AdminClient) Speedtest(ctx context.Context, opts SpeedtestOpts) (chan
 	if opts.NoClear {
 		queryVals.Set("noclear", "true")
 	}
+	if opts.EnableSha256 {
+		queryVals.Set("enableSha256", "true")
+	}
 	resp, err := adm.executeMethod(ctx,
 		http.MethodPost, requestData{
 			relPath:     adminAPIPrefix + "/speedtest",
