@@ -49,6 +49,8 @@ const (
 	TraceBatchReplication
 	// TraceBatchKeyRotation will trace batch keyrotation operations.
 	TraceBatchKeyRotation
+	// TraceBatchExpire will trace batch expiration operations.
+	TraceBatchExpire
 	// TraceRebalance will trace rebalance operations
 	TraceRebalance
 	// TraceReplicationResync will trace replication resync operations.
@@ -66,6 +68,11 @@ const (
 	TraceAll TraceType = (1 << iota) - 1
 )
 
+const (
+	// TraceBatch will trace all batch operations.
+	TraceBatch = TraceBatchReplication | TraceBatchKeyRotation | TraceBatchExpire // |TraceBatch<NextFeature>
+)
+
 // Contains returns whether all flags in other is present in t.
 func (t TraceType) Contains(other TraceType) bool {
 	return t&other == other
